A vector of target values. If given as a factor, classification
will be performed, otherwise if an integer or numeric vector is given
neuralnet() will default to regression
nn.control
A named list with elements to be passed as control parameters to neuralnet(). Package defaults used if no values entered.
Value
An object of class nn which can be used with the neuralnet package as normal